pub fn intoval(c: u8) -> Result<u8, ParseHexError>
convert a byte from a hex string to its numeric value. use the tobyte function to convert a pair of hex characters to their actual byte representation.
tobyte